import React from 'react';
import ReactDOM from 'react-dom';
import { scaleSqrt, max, interpolateYlOrRd, scaleSequential } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { useCodes } from './useCodes';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const selectedYear = "2017";

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const codes = useCodes();

  if (!worldAtlas || !data || !codes) {
    return <pre>Loading...</pre>;
  }
  
  const filteredData = data.filter( d => d.Year === selectedYear);

  const nCodebyACode = new Map();
  codes.forEach(d => {
    const alpha3code = d['alpha-3'];
    const numericCode = d['country-code'];
    nCodebyACode.set(alpha3code, numericCode);
  });
    
  const rowByNumericCode = new Map();
  filteredData.forEach(d => {
    const alpha3code = d.Code;
    const numericCode = nCodebyACode.get(alpha3code);
    rowByNumericCode.set(numericCode, d);
  });
    
  console.log(rowByNumericCode)
  
  const colorValue = d => d.aids;
  const colorScale = scaleSequential(interpolateYlOrRd)
    .domain([0, max(data, colorValue)])
  
  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        rowByNumericCode={rowByNumericCode}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
